==> events-0.22.0-sources.jar: software/amazon/awscdk/services/events/IEventRule.java <==
package software.amazon.awscdk.services.events;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.13 (build 311bf88)", date = "2019-01-11T10:48:42.406Z")
public interface IEventRule extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.IConstruct {
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    java.lang.String getRuleArn();
    /**
     * Exports this rule resource from this stack and returns an import token.
     */
    software.amazon.awscdk.services.events.EventRuleImportProps export();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.IEventRule {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public java.lang.String getRuleArn() {
            return this.jsiiGet("ruleArn", java.lang.String.class);
        }

        /**
         * The construct node in the scope tree.
         */
        @Override
        public software.amazon.awscdk.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.ConstructNode.class);
        }

        /**
         * Exports this rule resource from this stack and returns an import token.
         */
        @Override
        public software.amazon.awscdk.services.events.EventRuleImportProps export() {
            return this.jsiiCall("export", software.amazon.awscdk.services.events.EventRuleImportProps.class);
        }
    }
}

==> events-0.23.0-sources.jar: software/amazon/awscdk/services/events/IEventRule.java <==
package software.amazon.awscdk.services.events;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.14 (build 91853ce)", date = "2019-02-04T14:53:02.184Z")
public interface IEventRule extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.IConstruct {
    /**
     * The value of the event rule Amazon Resource Name (ARN), such as
     * arn:aws:events:us-east-2:123456789012:rule/example.
     */
    java.lang.String getRuleArn();
    /**
     * Exports this rule resource from this stack and returns an import token.
     */
    software.amazon.awscdk.services.events.EventRuleImportProps export();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.IEventRule {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * The value of the event rule Amazon Resource Name (ARN), such as
         * arn:aws:events:us-east-2:123456789012:rule/example.
         */
        @Override
        public java.lang.String getRuleArn() {
            return this.jsiiGet("ruleArn", java.lang.String.class);
        }

        /**
         * The construct node in the scope tree.
         */
        @Override
        public software.amazon.awscdk.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.ConstructNode.class);
        }

        /**
         * The set of constructs that form the root of this dependable
         * 
         * All resources under all returned constructs are included in the ordering
         * dependency.
         */
        @Override
        public java.util.List<software.amazon.awscdk.IConstruct> getDependencyRoots() {
            return this.jsiiGet("dependencyRoots", java.util.List.class);
        }

        /**
         * Exports this rule resource from this stack and returns an import token.
         */
        @Override
        public software.amazon.awscdk.services.events.EventRuleImportProps export() {
            return this.jsiiCall("export", software.amazon.awscdk.services.events.EventRuleImportProps.class);
        }
    }
}
